@@ -149,10 +149,6 @@ KFontChooser::~KFontChooser() = default;
 
 void KFontChooserPrivate::init()
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
-    m_ui->fontFeaturesLabel->setVisible(false);
-    m_ui->fontFeaturesLineEdit->setVisible(false);
-#endif
     m_usingFixed = m_flags & KFontChooser::FixedFontsOnly;
 
     // The main layout is divided horizontally into a top part with
@@ -166,6 +162,7 @@ void KFontChooserPrivate::init()
 
     m_ui.reset(new Ui_KFontChooserWidget);
     m_ui->setupUi(page);
+
     // Increase spacing on top of the preview field and then reset the other layouts
     // back to a standard value.
     m_ui->sampleTextEditLayout->setSpacing(q->style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
@@ -621,7 +618,6 @@ void KFontChooserPrivate::slotSizeValue(double dval)
 
 void KFontChooserPrivate::slotFeaturesChanged(const QString &features)
 {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
     m_selectedFont.clearFeatures();
 
     if (features.isEmpty()) {
@@ -651,7 +647,6 @@ void KFontChooserPrivate::slotFeaturesChanged(const QString &features)
     }
 
     Q_EMIT q->fontSelected(m_selectedFont);
-#endif
 }
 
 void KFontChooserPrivate::displaySample(const QFont &font)
@@ -747,7 +742,6 @@ void KFontChooserPrivate::setupDisplay()
     }
 
     // Set font features
-#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
     const auto tags = m_selectedFont.featureTags();
     QStringList features;
     for (const auto &tag : tags) {
@@ -760,7 +754,6 @@ void KFontChooserPrivate::setupDisplay()
         }
     }
     m_ui->fontFeaturesLineEdit->setText(features.join(QStringLiteral(",")));
-#endif
 
     int numEntries;
     int i;
